@@ -1,4 +1,4 @@
-from typing import List
+from typing import List, Dict, Union
 
 GRADES = [
     "AA",
@@ -49,14 +49,16 @@ class Person:
         else:
             raise Exception
 
-    def to_dict(self) -> dict:
+    def to_dict(
+        self,
+    ) -> Dict[str, Dict[str, Union[str, List[Dict[str, Dict[str, str]]]]]]:
         output = self.core_to_dict()
-        output["connections"] = [
+        output[self.__class__.__name__.lower()]["connections"] = [
             connection.core_to_dict() for connection in self.connections
         ]
         return output
 
-    def core_to_dict(self):
+    def core_to_dict(self) -> Dict[str, Dict[str, Union[str, List]]]:
         return {
             self.__class__.__name__.lower(): {
                 "email": self.email,
@@ -77,6 +79,10 @@ class Person:
                     output[f"match {i + 1} {key}"] = value
         return output
 
-    def __eq__(self, other):
-        if type(other) == type(self):
-            return other.to_dict() == self.to_dict()
+    def class_name(self):
+        return self.__class__.__name__.lower()
+
+    def __eq__(self, other: "Person"):
+        return other.to_dict().get(other.class_name()) == self.to_dict().get(
+            self.class_name()
+        )
